@@ -734,18 +734,21 @@ def _list_keys(context, key_prefix, delimiter):
         keys = []
         directories = []
         if 'Contents' in response:
-            for item in response.Contents:
-                key = item.Key
-                last_modified_str = item.LastModified
-                last_modified = datetime.datetime.strptime(
+            for item in response['Contents']:
+                key = item['Key']
+                last_modified_str = item['LastModified']
+                if isinstance(last_modified_str, str):
+                    last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
+                else:
+                    last_modified = datetime.datetime.strptime(
                     last_modified_str, "%Y-%m-%dT%H:%M:%S.%fZ")
                 keys.append((key, last_modified))
         if 'CommonPrefixes' in response:
             # Prefixes end in '/', which we strip off
-            for item in response.CommonPrefixes:
-                directories.append(item.Prefix[:-1])
+            for item in response['CommonPrefixes']:
+                directories.append(item['Prefix'][:-1])
         if 'NextContinuationToken' in response:
-            next_token = response.NextContinuationToken
+            next_token = response['NextContinuationToken']
         print((next_token, keys, directories))
         return (next_token, keys, directories)
 
